@@ -1,11 +1,11 @@
 path.profile <- function(path,bathy,plot=FALSE,...) {
-	
-	if (class(bathy)!="bathy") stop("Object bathy is not of class bathy")
+
+  if (!is(bathy, "bathy")) stop("Object bathy is not of class bathy")
 	if (ncol(path)!=2) stop("Object path should have 2 columns: Longitude and Latitude")
-	
+
 	out <- matrix(0,ncol=4)
 	colnames(out) <- c("lon","lat","dist.km","depth")
-	
+
 	for (i in 1:(nrow(path)-1)) {
 		df <- get.transect(mat=bathy, x1=path[i,1], y1=path[i,2],x2=path[i+1,1],y2=path[i+1,2],distance=TRUE)
 		# df <- df[-1,]
@@ -18,7 +18,7 @@ path.profile <- function(path,bathy,plot=FALSE,...) {
 	if (plot){
 		dev.new()
 		plotProfile(out,...)
-	} 
+	}
 	return(out)
 }
 
